@@ -10,14 +10,14 @@ require HTML::DOM::Element;
 require HTML::DOM::NodeList::Magic;
 #require HTML::DOM::Collection::Elements;
 
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = qw'HTML::DOM::Element';
 
 use overload fallback => 1,
 '@{}' => sub { shift->elements },
 '%{}' => sub {
 	my $self = shift;
-	$self->isa(scalar caller) || caller->isa('HTML::TreeBuilder')
+	$self->isa(scalar caller) || caller->isa('HTML::DOM::_TreeBuilder')
 		and return $self;
 	$self->elements;
 };
@@ -412,7 +412,7 @@ package HTML::DOM::NodeList::Radio; # solely for HTML::Form compatibility
 use Carp 'croak';
 require HTML::DOM::NodeList;
 
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = qw'HTML::DOM::NodeList';
 
 sub type { 'radio' }
@@ -484,7 +484,7 @@ use warnings;
 
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 
 require HTML::DOM::Collection;
 our @ISA = 'HTML::DOM::Collection';
@@ -661,7 +661,7 @@ L<HTML::Form>
 # ------- HTMLSelectElement interface ---------- #
 
 package HTML::DOM::Element::Select;
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = 'HTML::DOM::Element';
 
 use overload fallback=>1, '@{}' => sub { shift->options };
@@ -754,7 +754,7 @@ package HTML::DOM::Collection::Options;
 use strict;
 use warnings;
 
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 
 use Carp 'croak';
 use constant sel => 5; # must not conflict with super
@@ -832,7 +832,7 @@ sub length { # override
 # ------- HTMLOptGroupElement interface ---------- #
 
 package HTML::DOM::Element::OptGroup;
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = 'HTML::DOM::Element';
 
 sub label  { shift->_attr( label => @_) }
@@ -842,7 +842,7 @@ sub label  { shift->_attr( label => @_) }
 # ------- HTMLOptionElement interface ---------- #
 
 package HTML::DOM::Element::Option;
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -955,7 +955,7 @@ sub _reset { delete shift->{_HTML_DOM_sel} }
 # ------- HTMLInputElement interface ---------- #
 
 package HTML::DOM::Element::Input;
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -1177,7 +1177,7 @@ sub content {
 # ------- HTMLTextAreaElement interface ---------- #
 
 package HTML::DOM::Element::TextArea;
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = qw'HTML::DOM::Element';
 
 sub defaultValue { # same as HTML::DOM::Element::Title::text
@@ -1225,7 +1225,7 @@ sub _reset {
 # ------- HTMLButtonElement interface ---------- #
 
 package HTML::DOM::Element::Button;
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1282,7 +1282,7 @@ sub _reset {}
 # ------- HTMLLabelElement interface ---------- #
 
 package HTML::DOM::Element::Label;
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1292,7 +1292,7 @@ sub htmlFor { shift->_attr( for       => @_) }
 # ------- HTMLFieldSetElement interface ---------- #
 
 package HTML::DOM::Element::FieldSet;
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1300,7 +1300,7 @@ our @ISA = qw'HTML::DOM::Element';
 # ------- HTMLLegendElement interface ---------- #
 
 package HTML::DOM::Element::Legend;
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
